Index: sites/trunk/wordpress.org/public_html/wp-content/plugins/wporg-bbp-topic-resolution/inc/class-plugin.php
===================================================================
--- sites/trunk/wordpress.org/public_html/wp-content/plugins/wporg-bbp-topic-resolution/inc/class-plugin.php	(revision 4899)
+++ sites/trunk/wordpress.org/public_html/wp-content/plugins/wporg-bbp-topic-resolution/inc/class-plugin.php	(working copy)
@@ -77,8 +77,8 @@
 			return $title;
 		}
 
-		// Don't run when viewing a single topic or a topic edit page.
-		if ( bbp_is_single_topic() || bbp_is_topic_edit() ) {
+		// Don't run when viewing a single topic, a topic edit page, or a reply edit page.
+		if ( bbp_is_single_topic() || bbp_is_topic_edit() || bbp_is_reply_edit() ) {
 			return $title;
 		}
 
